@@ -13,6 +13,9 @@ class ROIPaintImageViewModule(ROIImageViewModule):
     def __init__(self, main_widget, tab, settings_tab=True):
         super(ROIPaintImageViewModule, self).__init__(main_widget, tab, settings_tab)
         # part about selecting pixels
+        self.setMouseTracking(True)
+        self.image_view.setMouseTracking(True)
+        self.image_view.QMouseEvent = lambda x: self.mouse_move(x)
 
         self.select_pixel_on = False  # whether you can currently select pixels in the image
         self.brush_size = 1
@@ -23,10 +26,15 @@ class ROIPaintImageViewModule(ROIImageViewModule):
                                                      dtype=bool)  # mask 1 when selected 0 when not
         self.shape = self.data_handler.shape
         self.select_image_flat = np.zeros([self.shape[0] * self.shape[1], 3])
+        self.halo_image_flat = np.zeros(
+            [self.shape[0] * self.shape[1], 3])  # used for cursor halo
         self.select_pixel_color = [0, 255, 0]
         self.select_mode = "add"  # possibilities add and subtract from current
         # selection
 
+    def mouse_move(self, event):
+        if event.type() == QtCore.Qt.MouseMove:
+            print(event.pos().x())
     def roi_view_click(self, event):
         if event.button() == QtCore.Qt.RightButton:
             if self.image_item.raiseContextMenu(event):
@@ -97,7 +105,8 @@ class ROIPaintImageViewModule(ROIImageViewModule):
                 shape[1] * x_new + y_new)
             self.current_selected_pixels_mask[x_new, y_new] = True
         self.image_item.updateImage()
-        self.main_widget.console.updateText("Successfully generated selection of size: %s" % str(len(new_roi)))
+        self.main_widget.console.updateText(
+            "Successfully generated selection of size: %s" % str(len(new_roi)))
 
         return True
     def pixel_paint(self, x, y):
@@ -147,10 +156,10 @@ class ROIPaintImageViewModule(ROIImageViewModule):
             # range_list = self.main_widget.roi_image_view.image_view.view.viewRange()
             background_max = np.percentile(self.current_background, 98)
             background_min = np.percentile(self.current_background, 2)
-            background_image_scaled = (self.current_foreground_intensity/10 * (
-                        self.current_background - background_min) * 235 / (
+            background_image_scaled = (self.current_foreground_intensity / 10 * (
+                    self.current_background - background_min) * 235 / (
                                            (background_max - background_min) if (
-                                                                                            background_max - background_min) != 0 else 1))
+                                                                                        background_max - background_min) != 0 else 1))
             background_image_scaled_3_channel = np.hstack(
                 [background_image_scaled, background_image_scaled,
                  background_image_scaled])
