@@ -35,9 +35,6 @@ class PreprocessingTab(Tab):
         main_widget.thread_list.append(thread)  # Appends the thread to the main
         # widget thread list
         process_button.clicked.connect(lambda: thread.runThread())
-        # This assumes that the data is already loaded in
-        self.data_handler.calculate_filters()
-
 
         # Section that creates all the buttons to change which image is displayed
         image_buttons = QWidget()
@@ -133,7 +130,7 @@ class PreprocessingTab(Tab):
         # if button != None:
         #     button.setStyleSheet("QPushButton {border 1px solid #148CD2; }")
         self.trial_selector_input = OptionInput("", "", set_image, val_list=trial_names,
-                                                tool_tip="Select Trial to display",
+                                                tool_tip="Select time block to display",
                                                 display_tool_tip=False, default_index=0,
                                                 show_name=False)
         self.trial_selector_input.input_box.setCurrentIndex(current)
