@@ -36,7 +36,7 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
                  eigen_threshold_method: bool,
                  eigen_threshold_value: float, merge_temporal_coef: float,
                  roi_size_max: int, pca: bool, pca_data: np.ndarray,
-                 eigen_accuracy: int):
+                 eigen_accuracy: int, progress_signal=None):
     logger1.debug("""Inputs: num_threads {0},test_images {1}, test_output_dir {2},
                  save_dir {3}, save_intermediate_steps {4},
                  load_data {5}, data_path {6},
@@ -102,7 +102,7 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
     # print("Creating {} spatial boxes".format(total_num_spatial_boxes))
     printProgressBarROI(total_num_spatial_boxes=total_num_spatial_boxes,
                         total_num_time_steps=total_num_time_steps,
-                        save_dir=save_dir)
+                        save_dir=save_dir, progress_signal=progress_signal)
     spatial_boxes = [SpatialBox(box_num=x, total_boxes=total_num_spatial_boxes,
                                 spatial_overlap=spatial_overlap, image_shape=shape)
                      for x in range(total_num_spatial_boxes)]
@@ -156,7 +156,8 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
                     spatial_box_num=spatial_box.box_num,
                     temporal_box_num=temporal_box_num,
                     total_num_spatial_boxes=total_num_spatial_boxes,
-                    total_num_time_steps=total_num_time_steps, save_dir=save_dir)
+                    total_num_time_steps=total_num_time_steps, save_dir=save_dir,
+                    progress_signal=progress_signal)
                 eigen_vectors = generateEigenVectors(K=k,
                                                      num_eig=time_box_data_2d_pca.shape[
                                                          1] if pca and False and num_eig >
@@ -215,7 +216,7 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
                                  box_num=spatial_box.box_num, print_progress=True,
                                  total_num_time_steps=total_num_time_steps,
                                  total_num_spatial_boxes=total_num_spatial_boxes,
-                                 save_dir=save_dir)
+                                 save_dir=save_dir, progress_signal=progress_signal)
         if test_images:
             pass
             # delayed(save_roi_images)(
